Struct ZwpFullscreenShellModeFeedbackV1
pub struct ZwpFullscreenShellModeFeedbackV1 { /* private fields */ }wayland and Linux only.Expand description
zwp_fullscreen_shell_mode_feedback_v1
This interface has no requests.
Implementations
impl ZwpFullscreenShellModeFeedbackV1
impl ZwpFullscreenShellModeFeedbackV1
pub fn mode_successful(&self)
pub fn mode_successful(&self)
mode switch succeeded
This event indicates that the attempted mode switch operation was successful. A surface of the size requested in the mode switch will fill the output without scaling.
Upon receiving this event, the client should destroy the wl_fullscreen_shell_mode_feedback object.
pub fn mode_failed(&self)
pub fn mode_failed(&self)
mode switch failed
This event indicates that the attempted mode switch operation failed. This may be because the requested output mode is not possible or it may mean that the compositor does not want to allow it.
Upon receiving this event, the client should destroy the wl_fullscreen_shell_mode_feedback object.
pub fn present_cancelled(&self)
pub fn present_cancelled(&self)
mode switch cancelled
This event indicates that the attempted mode switch operation was cancelled. Most likely this is because the client requested a second mode switch before the first one completed.
Upon receiving this event, the client should destroy the wl_fullscreen_shell_mode_feedback object.